%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CALCULATION OF LIFE CYCLE ENVIRONMENTAL IMPACTS DUE TO HEATING OF
% BUILDINGS IN TRONDHEIM
%
% Johanne Hammervold
% Date started: 18.06.2007
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% ABBREVIATIONS 
% (Dimensions for vectors and matrices are given in paranthese)
% imp = impact categories 
% com = energy commodities
% inf = infrastructure 
% pro = energy commodities and infrastructure
% y(pro) = consumption vector
% i(imp) = impact vector (one for each com, calculated using LCA)
% I(imp,pro) = impact matrix
% d(imp) = vector of total impacts per impact category 
% D_pro(imp,pro) = matrix of impacts per impact category and energy commodity/infrastructure  
% a = NORDEL electricity production mix
% b = Norwegian electricity production mix
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all

disp('Load the impact vectors from SimaPro...')

% ENERGY COMMODITIES
disp('Waste incineration')
i_wasteinc = xlsread('Impact vectors','imp vectors', 'D7:D16');
disp('Light fuel oil, burned in boiler, 100 kW')
i_lfo_priv = xlsread('Impact vectors','imp vectors', 'E7:E16');
disp('Light fuel oil burned in industrial furnace, 1 MW')
i_lfo_ind = xlsread('Impact vectors','imp vectors', 'F7:F16');
disp('Heavy fuel oil burned in industrial furnace')
i_hfo_ind = xlsread('Impact vectors','imp vectors', 'G7:G16');
disp('Pellets burned in boiler, 15 kW')
i_pellets_priv = xlsread('Impact vectors','imp vectors', 'H7:H16');
disp('Pellets burned in furnace, 50 kW')
i_pellets_ind = xlsread('Impact vectors','imp vectors', 'I7:I16');
disp('Natural gas (distributed by pipe) burned in boiler, <100 kW')
i_gas_priv_pipe = xlsread('Impact vectors','imp vectors', 'J7:J16');
disp('Natural gas (distributed by pipe) burned in industrial furnace, >100 kW')
i_gas_ind_pipe = xlsread('Impact vectors','imp vectors', 'K7:K16');
disp('Natural gas (distributed by lorry) burned in boiler, <100 kW')
i_gas_priv_lorry = xlsread('Impact vectors','imp vectors', 'L7:L16');
disp('Natural gas (distributed by lorry) burned in industrial furnace, >100 kW')
i_gas_ind_lorry = xlsread('Impact vectors','imp vectors', 'M7:M16');
disp('Liquiefied petroleum gas burned in boiler, 10 kW')
i_lpg_priv = xlsread('Impact vectors','imp vectors', 'N7:N16');
disp('Liquiefied petroleum gas burned in industrial furnace, 1 MW')
i_lpg_ind = xlsread('Impact vectors','imp vectors', 'O7:O16');
disp('Wood, norwegian mean for household consumption')
i_wood_priv = xlsread('Impact vectors','imp vectors', 'P7:P16');
% i_wood_priv = xlsread('Impact vectors','imp vectors', 'T7:T16');
% WOOD: P: SimaPro results, T: results from Martes LCA
disp('Electricity, end user, NORDEL production mix')
i_el_nordel = xlsread('Impact vectors','imp vectors', 'Q7:Q16');
disp('Electricity, end user, Norwegian production mix')
i_el_no = xlsread('Impact vectors','imp vectors', 'R7:R16');

% INFRASTRUCTURE
disp('Electricity grid, Low voltage')
i_elgrid_low = xlsread('Impact vectors','imp vectors', 'C22:C31');
disp('Electricity grid, Medium voltage')
i_elgrid_med = xlsread('Impact vectors','imp vectors', 'D22:D31');
disp('Electricity grid, High voltage')
i_elgrid_high = xlsread('Impact vectors','imp vectors', 'E22:E31');
disp('DH grid, DN25 Twin')
i_DN25_t = xlsread('Impact vectors','imp vectors', 'F22:F31');
disp('DH grid, DN25 Single')
i_DN25_s = xlsread('Impact vectors','imp vectors', 'G22:G31');
disp('DH grid, DN100 Single')
i_DN100_s = xlsread('Impact vectors','imp vectors', 'H22:H31');
disp('DH grid, DN500 Single')
i_DN500_s = xlsread('Impact vectors','imp vectors', 'I22:I31');
disp('Natural gas pipeline, low pressure')
i_gaspipe_low = xlsread('Impact vectors','imp vectors', 'J22:J31');
disp('Natural gas pipeline, high pressure')
i_gaspipe_high = xlsread('Impact vectors','imp vectors', 'K22:K31');
disp('Transport, waste, locally')
i_trsp_waste_local = xlsread('Impact vectors','imp vectors', 'L22:L31');
disp('Transport, waste, long')
i_trsp_waste_long = xlsread('Impact vectors','imp vectors', 'M22:M31');
disp('Transport, special waste')
i_trsp_spec_waste = xlsread('Impact vectors','imp vectors', 'N22:N31');
disp('Transport, oil products')
i_trsp_oilprod = xlsread('Impact vectors','imp vectors', 'O22:O31');
disp('Waste incineration plant')
i_wasteinc_plant = xlsread('Impact vectors','imp vectors', 'O22:O31');

% COLLECT IMPACT VECTORS IN ONE MATRIX
% Energy commodities, NORDEL el mix:
I_com_a = [i_wasteinc, i_lfo_priv, i_lfo_ind, i_pellets_ind, i_gas_ind_lorry, i_lpg_priv, i_lpg_ind, i_wood_priv, i_hfo_ind, i_el_nordel];
% Energy commodities, Norwegian el mix:
I_com_b = [i_wasteinc, i_lfo_priv, i_lfo_ind, i_pellets_ind, i_gas_ind_lorry, i_lpg_priv, i_lpg_ind, i_wood_priv, i_hfo_ind, i_el_no];
% Infrastructure:
I_inf = [i_DN25_t, i_DN25_s, i_DN100_s, i_DN500_s, i_elgrid_low, i_elgrid_med, i_elgrid_high, i_trsp_waste_local, i_trsp_waste_long, i_trsp_spec_waste];
% Energy commodities and infrastructure, NORDEL el mix:
I_a = [I_com_a, I_inf];
% Energy commodities and infrastructure, Norwegian el mix:
I_b = [I_com_b, I_inf];



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRONDHEIM CASE, BASE SCENARIO (Based on consumption statistics for 2004)%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% LOADING CONSUMPTION
% Vector for consumption of energy commodities:
y_base_com = xlsread('Scenarios','Til Matlab', 'D4:D13');
% Vector for consumption of infrastructure:
y_base_inf = xlsread('Scenarios','Til Matlab', 'D16:D25');
% Vector for total consumption, base scenario
y_base = [y_base_com; y_base_inf];  

% TOTAL IMPACTS, BASE SCENARIO
% Vector of total impacts per impact category, NORDEL el mix: 
d_base_a = I_a * y_base;
% Vector of total impacts per impact category, Norwegian el mix:
d_base_b = I_b * y_base;

% IMPACTS IN EACH CATEGORY AND ENERGY COMMODITY / INFRASTRUCTURE
D_pro_base_a = I_a * diag(y_base);
D_pro_base_b = I_b * diag(y_base);
% Aggregate: DH grid in one, El grid in one and waste ransport in one. 
D_pro_base_a_agg = [D_pro_base_a(:,1:10), D_pro_base_a(:,11)+D_pro_base_a(:,12)+D_pro_base_a(:,13)+D_pro_base_a(:,14), D_pro_base_a(:,15)+D_pro_base_a(:,16)+D_pro_base_a(:,17), D_pro_base_a(:,18)+D_pro_base_a(:,19)+D_pro_base_a(:,20)];
xlswrite('Dpro', D_pro_base_a_agg, 'D_pro', 'C27'); 



% COMPARISON OF EL MIX ALTERNATIVES
% Normalize the to el mix alternatives, relative to NORDEL el mix:
d_norm_base_a = inv(diag(d_base_a))*d_base_a;
d_norm_base_b = inv(diag(d_base_a))*d_base_b;

figure;
bar([d_norm_base_a d_norm_base_b]);
legend('NORDEL', 'Norwegian')
title('Normalized impacts per category for each electricity mix choice, base scenario');



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRONDHEIM CASE, SCENARIO 2013 (Based on prognosis for consumption)      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% LOADING CONSUMPTION
% Vector for consumption of energy commodities:
y_2013_com = xlsread('Scenarios','Til Matlab', 'D28:D37');
% Vector for consumption of infrastructure:
y_2013_inf = xlsread('Scenarios','Til Matlab', 'D40:D49');
% Vector for total consumption, 2013 scenario
y_2013 = [y_2013_com; y_2013_inf];  

% TOTAL IMPACTS, BASE SCENARIO
% Vector of total impacts per impact category, NORDEL el mix: 
d_2013_a = I_a * y_2013;
% Vector of total impacts per impact category, Norwegian el mix:
d_2013_b = I_b * y_2013;

% IMPACTS IN EACH CATEGORY AND ENERGY COMMODITY / INFRASTRUCTURE
D_pro_2013_a = I_a * diag(y_2013);
D_pro_2013_b = I_b * diag(y_2013);
% % Aggregate: DH grid and El grid assembled and waste transport iincluded in waste
% % incineration:
D_pro_2013_a_agg= [D_pro_2013_a(:,1:10), D_pro_2013_a(:,11)+D_pro_2013_a(:,12)+D_pro_2013_a(:,13)+D_pro_2013_a(:,14), D_pro_2013_a(:,15)+D_pro_2013_a(:,16)+D_pro_2013_a(:,17), D_pro_2013_a(:,18)+D_pro_2013_a(:,19)+D_pro_2013_a(:,20)];
xlswrite('Dpro', D_pro_2013_a_agg, 'D_pro', 'C40'); 

% COMPARISON OF EL MIX ALTERNATIVES
% Normalize the to el mix alternatives, relative to NORDEL el mix:
d_norm_2013_a = inv(diag(d_2013_a))*d_2013_a;
d_norm_2013_b = inv(diag(d_2013_a))*d_2013_b;

figure;
bar([d_norm_2013_a d_norm_2013_b]);
legend('NORDEL', 'Norwegian')
title('Normalized impacts per category for each electricity mix choice, 2013 scenario');



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMPARISON OF BASE SCENARIO AND 2013 SCENARIO, NORDEL EL MIX            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Normalize 2013 scenario and base scenario relative to base scenario:
d_norm_base_a = inv(diag(d_base_a))*d_base_a;
d_norm_2013_a = inv(diag(d_base_a))*d_2013_a;
figure;
bar([d_norm_base_a d_norm_2013_a]);
legend('2004', '2013')
title('Normalized impacts per category for each scenario, NORDEL el mix');

d_norm_base_b = inv(diag(d_base_b))*d_base_b;
d_norm_2013_b = inv(diag(d_base_b))*d_2013_b;
figure;
bar([d_norm_base_b d_norm_2013_b]);
% xlabel('ADP GWP ODP HTP FAETP MAETP TETP POCP AP EP')
legend('2004', '2013')
title('Normalized impacts per category for each scenario, Norwegian el mix');

% Export the total impact vectors for both scenarios and electricity mix:
xlswrite('Dpro', d_base_a, 'Results','C3');
xlswrite('Dpro', d_2013_a, 'Results','D3');
xlswrite('Dpro', d_base_b, 'Results','F3');
xlswrite('Dpro', d_2013_b, 'Results','G3');

% Export the D_com matrices to excel to obtain stacked bar charts:
xlswrite('Dpro', D_pro_base_a, 'D_pro','C3');
xlswrite('Dpro', D_pro_2013_a, 'D_pro','C14');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% WEIGHTING   - Netherlands, 1997 method                     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% w: weighting vector
w = xlsread('Impact vectors','imp vectors', 'V22:V31');
w_base_a = d_base_a' * w;
w_base_b = d_base_b' * w;
w_2013_a = d_2013_a' * w;
w_2013_b = d_2013_b' * w;
xlswrite('Dpro', w_base_a, 'Results','B18');
xlswrite('Dpro', w_base_b, 'Results','D18');
xlswrite('Dpro', w_2013_a, 'Results','C18');
xlswrite('Dpro', w_2013_b, 'Results','E18');
